@@ -1,3 +1,7 @@
+"""
+Validators for applying validations in sequence.
+"""
+
 from api import *
 
 # @@ ianb 2005-05: should CompoundValidator be included?
@@ -13,7 +17,7 @@ def to_python(validator, value, state):
 def from_python(validator, value, state):
     return validator.from_python(value, state)
 
-class CompoundValidator(Validator):
+class CompoundValidator(FancyValidator):
 
     if_invalid = NoDefault
 
@@ -48,14 +52,17 @@ class CompoundValidator(Validator):
     def attempt_convert(self, value, state, convertFunc):
         raise NotImplementedError, "Subclasses must implement attempt_convert"
 
-    def to_python(self, value, state=None):
+    def _to_python(self, value, state=None):
         return self.attempt_convert(value, state,
                                     to_python)
     
-    def from_python(self, value, state=None):
+    def _from_python(self, value, state=None):
         return self.attempt_convert(value, state,
                                     from_python)
 
+    def subvalidators(self):
+        return self.validators
+
 class Any(CompoundValidator):
     
     """
@@ -80,6 +87,13 @@ class Any(CompoundValidator):
         else:
             return self.if_invalid
 
+    def not_empty__get(self):
+        not_empty = True
+        for validator in self.validators:
+            not_empty = not_empty and validator.not_empty
+        return not_empty
+    not_empty = property(not_empty__get)
+
 class All(CompoundValidator):
 
     """
@@ -144,3 +158,10 @@ class All(CompoundValidator):
                 return v
         return NoDefault
     if_missing = property(if_missing__get)
+
+    def not_empty__get(self):
+        not_empty = False
+        for validator in self.validators:
+            not_empty = not_empty or validator.not_empty
+        return not_empty
+    not_empty = property(not_empty__get)
